pub struct CTabList {
pub header: TextComponent,
pub footer: TextComponent,
}Expand description
Packet to set the tab list header and footer. This allows servers to display custom text above and below the player list.
Fields
header: TextComponentThe header text component (displayed above the player list)
The footer text component (displayed below the player list)
Implementations
Sourceimpl CTabList
impl CTabList
Sourcepub fn new<T: TextResolutor>(
header: &TextComponent,
footer: &TextComponent,
player: &T,
) -> Self
pub fn new<T: TextResolutor>( header: &TextComponent, footer: &TextComponent, player: &T, ) -> Self
Creates a new tab list packet with the specified header and footer.
Sourcepub const fn empty() -> Self
pub const fn empty() -> Self
Creates a tab list packet with empty header and footer (clears them).
Sourcepub fn header_only<T: TextResolutor>(header: &TextComponent, player: &T) -> Self
pub fn header_only<T: TextResolutor>(header: &TextComponent, player: &T) -> Self
Creates a tab list packet with only a header.
Creates a tab list packet with only a footer.